#ifndef OPT_ROSTER_H
#define OPT_ROSTER_H

#include "optionstab.h"

class OptionsTabRoster : public MetaOptionsTab {
    Q_OBJECT
public:
    OptionsTabRoster(QObject *parent);
};

#endif // OPT_ROSTER_H
